@@ -8,14 +8,12 @@
 
 """Invenio-Records-REST configuration."""
 
-from __future__ import absolute_import, print_function
-
 from flask import request
 from invenio_indexer.api import RecordIndexer
 from invenio_search import RecordsSearch
 
 from .facets import terms_filter
-from .utils import allow_all, check_elasticsearch, deny_all
+from .utils import allow_all, check_search, deny_all
 
 
 def _(x):
@@ -25,24 +23,24 @@ def _(x):
 
 RECORDS_REST_ENDPOINTS = dict(
     recid=dict(
-        pid_type='recid',
-        pid_minter='recid',
-        pid_fetcher='recid',
+        pid_type="recid",
+        pid_minter="recid",
+        pid_fetcher="recid",
         search_class=RecordsSearch,
         indexer_class=RecordIndexer,
         search_index=None,
         search_type=None,
         record_serializers={
-            'application/json': ('invenio_records_rest.serializers'
-                                 ':json_v1_response'),
+            "application/json": (
+                "invenio_records_rest.serializers" ":json_v1_response"
+            ),
         },
         search_serializers={
-            'application/json': ('invenio_records_rest.serializers'
-                                 ':json_v1_search'),
+            "application/json": ("invenio_records_rest.serializers" ":json_v1_search"),
         },
-        list_route='/records/',
-        item_route='/records/<pid(recid):pid_value>',
-        default_media_type='application/json',
+        list_route="/records/",
+        item_route="/records/<pid(recid):pid_value>",
+        default_media_type="application/json",
         max_result_window=10000,
         error_handlers=dict(),
     ),
@@ -112,19 +110,19 @@ The structure of the dictionary is as follows:
             },
             'search_class': 'mypackage.utils:mysearchclass',
             'search_factory_imp': search_factory(),
-            'search_index': 'elasticsearch-index-name',
+            'search_index': 'search-index-name',
             'search_serializers': {
                 'application/json': 'mypackage.utils:my_json_search_serializer'
             },
             'search_serializers_aliases': {
                 'json': 'application/json'
             },
-            'search_type': 'elasticsearch-doc-type',
+            'search_type': 'search-doc-type',
             'suggesters': {
                 'my_url_param_to_complete': {
                     '_source': ['specified_source_filtered_field'],
                     'completion': {
-                        'field': 'suggest_byyear_elasticsearch_field',
+                        'field': 'suggest_byyear_search_field',
                         'size': 10,
                         'context': 'year'
                     }
@@ -191,7 +189,7 @@ The structure of the dictionary is as follows:
     :class:`invenio_search.api.RecordsSearch`.
     For more information about resource loading, see the `Search
     <http://elasticsearch-dsl.readthedocs.io/en/latest/search_dsl.html>` of the
-    ElasticSearch DSL library.
+    the search engine DSL library.
 
 :param search_factory_imp: Factory to parse queries.
 
@@ -213,9 +211,9 @@ The structure of the dictionary is as follows:
     optionally specify the source filtering (appropriate for ES5) by using
     ``_source``. The key of the dictionary element is used to identify the url
     query parameter. The ``field`` parameter identifies the suggester field
-    name in your elasticsearch schema.
+    name in your search engine schema.
     To have more information about suggestion configuration, you can read
-    suggesters section on ElasticSearch documentation.
+    suggesters section on the search engine documentation.
 
     .. note:: Only completion suggesters are supported.
 
@@ -234,8 +232,8 @@ The structure of the dictionary is as follows:
 """
 
 RECORDS_REST_DEFAULT_LOADERS = {
-    'application/json': lambda: request.get_json(),
-    'application/json-patch+json': lambda: request.get_json(force=True),
+    "application/json": lambda: request.get_json(),
+    "application/json-patch+json": lambda: request.get_json(force=True),
 }
 """Default data loaders per request mime type.
 
@@ -258,15 +256,15 @@ This option can be overritten in each REST endpoint as follows:
 RECORDS_REST_SORT_OPTIONS = dict(
     records=dict(
         bestmatch=dict(
-            title=_('Best match'),
-            fields=['_score'],
-            default_order='desc',
+            title=_("Best match"),
+            fields=["_score"],
+            default_order="desc",
             order=1,
         ),
         mostrecent=dict(
-            title=_('Most recent'),
-            fields=['-_created'],
-            default_order='asc',
+            title=_("Most recent"),
+            fields=["-_created"],
+            default_order="asc",
             order=2,
         ),
     )
@@ -291,7 +289,7 @@ Each search field can be either:
 
 - A string of the form ``'<field name>'`` (ascending) or ``'-<field name>'``
   (descending).
-- A dictionary with Elasticsearch sorting syntax (e.g.
+- A dictionary with search engine sorting syntax (e.g.
   ``{'price' : {'order' : 'asc', 'mode' : 'avg'}}``).
 - A callable taking one boolean parameter (``True`` for ascending and ``False``
   for descending) and returning a dictionary like above. This is useful if you
@@ -300,8 +298,8 @@ Each search field can be either:
 
 RECORDS_REST_DEFAULT_SORT = dict(
     records=dict(
-        query='bestmatch',
-        noquery='mostrecent',
+        query="bestmatch",
+        noquery="mostrecent",
     )
 )
 """Default sort option per index with/without query string.
@@ -320,12 +318,10 @@ The structure of the dictionary is as follows:
 
 RECORDS_REST_FACETS = dict(
     records=dict(
-        aggs=dict(
-            type=dict(terms=dict(field='type'))
-        ),
+        aggs=dict(type=dict(terms=dict(field="type"))),
         post_filters=dict(
-            type=terms_filter('type'),
-        )
+            type=terms_filter("type"),
+        ),
     )
 )
 """Facets per index for the default facets factory.
@@ -358,7 +354,7 @@ RECORDS_REST_DEFAULT_CREATE_PERMISSION_FACTORY = deny_all
 RECORDS_REST_DEFAULT_LIST_PERMISSION_FACTORY = allow_all
 """Default list permission factory: allow all requests"""
 
-RECORDS_REST_DEFAULT_READ_PERMISSION_FACTORY = check_elasticsearch
+RECORDS_REST_DEFAULT_READ_PERMISSION_FACTORY = check_search
 """Default read permission factory: check if the record exists."""
 
 RECORDS_REST_DEFAULT_UPDATE_PERMISSION_FACTORY = deny_all
@@ -367,17 +363,14 @@ RECORDS_REST_DEFAULT_UPDATE_PERMISSION_FACTORY = deny_all
 RECORDS_REST_DEFAULT_DELETE_PERMISSION_FACTORY = deny_all
 """Default delete permission factory: reject any request."""
 
-RECORDS_REST_ELASTICSEARCH_ERROR_HANDLERS = {
-    'query_parsing_exception': (
-        'invenio_records_rest.views'
-        ':elasticsearch_query_parsing_exception_handler'
+RECORDS_REST_SEARCH_ERROR_HANDLERS = {
+    "query_parsing_exception": (
+        "invenio_records_rest.views" ":search_query_parsing_exception_handler"
     ),
-    'query_shard_exception': (
-        'invenio_records_rest.views'
-        ':elasticsearch_query_parsing_exception_handler'
+    "query_shard_exception": (
+        "invenio_records_rest.views" ":search_query_parsing_exception_handler"
     ),
 }
-"""Handlers for ElasticSearch error codes."""
 
 RECORDS_REST_DEFAULT_RESULTS_SIZE = 10
 """Default search results size."""
