@@ -13,8 +13,6 @@ external to an internal JSON presentation. The marshmallow schema further
 allows for advanced data validation.
 """
 
-from __future__ import absolute_import, print_function
-
 import json
 
 from flask import request
@@ -32,14 +30,11 @@ def _flatten_marshmallow_errors(errors, parents=()):
                 dict(
                     parents=parents,
                     field=field,
-                    message=' '.join(str(x) for x in error)
+                    message=" ".join(str(x) for x in error),
                 )
             )
         elif isinstance(error, dict):
-            res.extend(_flatten_marshmallow_errors(
-                error,
-                parents=parents + (field,)
-            ))
+            res.extend(_flatten_marshmallow_errors(error, parents=parents + (field,)))
     return res
 
 
@@ -52,28 +47,14 @@ class MarshmallowErrors(RESTValidationError):
 
     def __init__(self, errors):
         """Store marshmallow errors."""
-        self._it = None
         self.errors = _flatten_marshmallow_errors(errors)
-        super(MarshmallowErrors, self).__init__()
+        super().__init__()
 
     def __str__(self):
         """Print exception with errors."""
         return "{base}. Encountered errors: {errors}".format(
-            base=super(RESTValidationError, self).__str__(),
-            errors=self.errors)
-
-    def __iter__(self):
-        """Get iterator."""
-        self._it = iter(self.errors)
-        return self
-
-    def next(self):
-        """Python 2.7 compatibility."""
-        return self.__next__()  # pragma: no cover
-
-    def __next__(self):
-        """Get next file item."""
-        return next(self._it)
+            base=super().__str__(), errors=self.errors
+        )
 
     def get_body(self, environ=None, scope=None):
         """Get the request body."""
@@ -83,22 +64,23 @@ class MarshmallowErrors(RESTValidationError):
         )
 
         if self.errors:
-            body['errors'] = self.errors
+            body["errors"] = self.errors
 
         return json.dumps(body)
 
 
 def marshmallow_loader(schema_class):
     """Marshmallow loader for JSON requests."""
+
     def json_loader():
         request_json = request.get_json()
 
         context = {}
-        pid_data = request.view_args.get('pid_value')
+        pid_data = request.view_args.get("pid_value")
         if pid_data:
             pid, record = pid_data.data
-            context['pid'] = pid
-            context['record'] = record
+            context["pid"] = pid
+            context["record"] = record
         if marshmallow_version[0] < 3:
             result = schema_class(context=context).load(request_json)
             if result.errors:
@@ -113,6 +95,7 @@ def marshmallow_loader(schema_class):
                 raise MarshmallowErrors(error.messages)
 
         return result.data
+
     return json_loader
 
 
