@@ -8,11 +8,10 @@
 
 """REST API for Records."""
 
-from __future__ import absolute_import, print_function
-
 from flask import current_app
 from werkzeug.local import LocalProxy
 
 current_records_rest = LocalProxy(
-    lambda: current_app.extensions['invenio-records-rest'])
+    lambda: current_app.extensions["invenio-records-rest"]
+)
 """Proxy to an instance of ``_RecordRESTState``."""
