@@ -8,8 +8,6 @@
 
 """Date string field."""
 
-from __future__ import absolute_import, print_function
-
 import arrow
 from arrow.parser import ParserError
 from marshmallow import fields, missing
@@ -21,12 +19,10 @@ class DateString(fields.Date):
     def _serialize(self, value, attr, obj, **kwargs):
         """Serialize an ISO8601-formatted date."""
         try:
-            return super(DateString, self)._serialize(
-                arrow.get(value).date(), attr, obj, **kwargs)
+            return super()._serialize(arrow.get(value).date(), attr, obj, **kwargs)
         except ParserError:
             return missing
 
     def _deserialize(self, value, attr, data, **kwargs):
         """Deserialize an ISO8601-formatted date."""
-        return super(DateString, self)._deserialize(value, attr,
-                                                    data, **kwargs).isoformat()
+        return super()._deserialize(value, attr, data, **kwargs).isoformat()
