@@ -8,8 +8,6 @@
 
 """Trimmed string field."""
 
-from __future__ import absolute_import, print_function
-
 from marshmallow import fields
 
 
@@ -18,6 +16,5 @@ class TrimmedString(fields.String):
 
     def _deserialize(self, value, attr, data, **kwargs):
         """Deserialize string value."""
-        value = super(TrimmedString, self)._deserialize(
-            value, attr, data, **kwargs)
+        value = super()._deserialize(value, attr, data, **kwargs)
         return value.strip()
