@@ -8,8 +8,6 @@
 
 """Get record tests."""
 
-from __future__ import absolute_import, print_function
-
 from flask import url_for
 from helpers import get_json, record_url, to_relative_url
 
@@ -22,18 +20,18 @@ def test_item_get(app, test_records):
         res = client.get(record_url(pid))
         assert res.status_code == 200
         assert res.cache_control.no_cache
-        assert res.headers['ETag'] == '"{}"'.format(record.revision_id)
+        assert res.headers["ETag"] == '"{}"'.format(record.revision_id)
 
         # Check metadata
         data = get_json(res)
-        for k in ['id', 'created', 'updated', 'metadata', 'links']:
+        for k in ["id", "created", "updated", "metadata", "links"]:
             assert k in data
 
-        assert data['id'] == pid.pid_value
-        assert data['metadata'] == record.dumps()
+        assert data["id"] == pid.pid_value
+        assert data["metadata"] == record.dumps()
 
         # Check self links
-        client.get(to_relative_url(data['links']['self']))
+        client.get(to_relative_url(data["links"]["self"]))
         assert res.status_code == 200
         assert data == get_json(res)
 
@@ -47,17 +45,16 @@ def test_item_get_etag(app, test_records):
         assert res.status_code == 200
         assert res.cache_control.no_cache
 
-        etag = res.headers['ETag']
-        last_modified = res.headers['Last-Modified']
+        etag = res.headers["ETag"]
+        last_modified = res.headers["Last-Modified"]
 
         # Test request via etag
-        res = client.get(record_url(pid), headers={'If-None-Match': etag})
+        res = client.get(record_url(pid), headers={"If-None-Match": etag})
         assert res.status_code == 304
         assert res.cache_control.no_cache
 
         # Test request via last-modified.
-        res = client.get(
-            record_url(pid), headers={'If-Modified-Since': last_modified})
+        res = client.get(record_url(pid), headers={"If-Modified-Since": last_modified})
         assert res.status_code == 304
         assert res.cache_control.no_cache
 
@@ -66,8 +63,8 @@ def test_item_get_norecord(app, test_records):
     """Test INVALID record get request (GET .../records/<record_id>)."""
     with app.test_client() as client:
         # check that GET with non existing id will return 404
-        res = client.get(url_for(
-            'invenio_records_rest.recid_item', pid_value='0'),
+        res = client.get(
+            url_for("invenio_records_rest.recid_item", pid_value="0"),
         )
         assert res.status_code == 404
 
@@ -78,5 +75,5 @@ def test_item_get_invalid_mimetype(app, test_records):
         pid, record = test_records[0]
 
         # Check that GET with non accepted format will return 406
-        res = client.get(record_url(pid), headers=[('Accept', 'video/mp4')])
+        res = client.get(record_url(pid), headers=[("Accept", "video/mp4")])
         assert res.status_code == 406
